@@ -10,6 +10,7 @@ import json
 import time
 import base64
 import os
+import ssl
 
 from typing import Callable, Dict, Optional, Union
 from sseclient import SSEClient
@@ -76,6 +77,7 @@ class ListenQueue(threading.Thread):
         self.helper = helper
         self.callback = callback
         self.host = config["connection"]["host"]
+        self.use_ssl = config["connection"]["use_ssl"]
         self.port = config["connection"]["port"]
         self.user = config["connection"]["user"]
         self.password = config["connection"]["pass"]
@@ -135,9 +137,23 @@ class ListenQueue(threading.Thread):
             try:
                 # Connect the broker
                 self.pika_credentials = pika.PlainCredentials(self.user, self.password)
-                self.pika_parameters = pika.ConnectionParameters(
-                    self.host, self.port, "/", self.pika_credentials
-                )
+                if self.use_ssl:
+                    context = ssl.create_default_context()
+                    ssl_options = pika.SSLOptions(context, self.host)
+                    self.pika_parameters = pika.ConnectionParameters(
+                        host=self.host,
+                        port=self.port,
+                        virtual_host="/",
+                        credentials=self.pika_credentials,
+                        ssl_options=ssl_options,
+                    )
+                else:
+                    self.pika_parameters = pika.ConnectionParameters(
+                        host=self.host,
+                        port=self.port,
+                        virtual_host="/",
+                        credentials=self.pika_credentials,
+                    )
                 self.pika_connection = pika.BlockingConnection(self.pika_parameters)
                 self.channel = self.pika_connection.channel()
                 self.channel.basic_consume(
@@ -206,6 +222,7 @@ class StreamCatcher(threading.Thread):
         self.connector_last_event_id = connector_last_event_id
         self.last_event_id = last_event_id
         self.stream_connection_id = stream_connection_id
+        self.session = requests.session()
 
     def get_range(self, from_id):
         payload = {
@@ -214,7 +231,7 @@ class StreamCatcher(threading.Thread):
             "connectionId": self.stream_connection_id,
         }
         headers = {"Authorization": "Bearer " + self.opencti_token}
-        r = requests.post(
+        r = self.session.post(
             self.opencti_url + "/stream/history", json=payload, headers=headers
         )
         result = r.json()
@@ -224,8 +241,20 @@ class StreamCatcher(threading.Thread):
     def run(self):
         if self.connector_last_event_id:
             from_event_id = self.connector_last_event_id
-            from_event_timestamp = 0
+            # If from event ID is "-", start from the beginning
+            if from_event_id == "-":
+                from_event_timestamp = 0
+            # If from event ID is a "pure" timestamp
+            elif "-" not in str(from_event_id):
+                from_event_timestamp = int(from_event_id)
+            elif "-" in str(from_event_id):
+                from_event_timestamp = int(str(from_event_id).split("-")[0])
+            else:
+                from_event_timestamp = 0
             last_event_timestamp = int(self.last_event_id.split("-")[0])
+            if from_event_timestamp > last_event_timestamp:
+                from_event_timestamp = last_event_timestamp - 1
+                from_event_id = str(from_event_timestamp) + "-0"
             while (
                 from_event_timestamp <= last_event_timestamp
                 and from_event_id != self.last_event_id
@@ -351,13 +380,13 @@ class OpenCTIConnectorHelper:
         """
 
         try:
-            return (
-                None
-                if self.connector_state is None
-                else json.loads(self.connector_state)
-            )
+            if self.connector_state:
+                state = json.loads(self.connector_state)
+                if isinstance(state, dict) and state:
+                    return state
         except:
-            return None
+            pass
+        return None
 
     def listen(self, message_callback: Callable[[str, Dict], str]) -> None:
         """listen for messages and register callback function
@@ -518,12 +547,24 @@ class OpenCTIConnectorHelper:
         pika_credentials = pika.PlainCredentials(
             self.config["connection"]["user"], self.config["connection"]["pass"]
         )
-        pika_parameters = pika.ConnectionParameters(
-            self.config["connection"]["host"],
-            self.config["connection"]["port"],
-            "/",
-            pika_credentials,
-        )
+        if self.config["connection"]["use_ssl"]:
+            context = ssl.create_default_context()
+            ssl_options = pika.SSLOptions(context, self.config["connection"]["host"])
+            pika_parameters = pika.ConnectionParameters(
+                host=self.config["connection"]["host"],
+                port=self.config["connection"]["port"],
+                virtual_host="/",
+                credentials=pika_credentials,
+                ssl_options=ssl_options,
+            )
+        else:
+            pika_parameters = pika.ConnectionParameters(
+                host=self.config["connection"]["host"],
+                port=self.config["connection"]["port"],
+                virtual_host="/",
+                credentials=pika_credentials,
+            )
+
         pika_connection = pika.BlockingConnection(pika_parameters)
         channel = pika_connection.channel()
         for sequence, bundle in enumerate(bundles, start=1):
