@@ -1,8 +1,6 @@
 # coding: utf-8
 
 import json
-from pycti.utils.constants import CustomProperties
-from pycti.utils.opencti_stix2 import SPEC_VERSION
 
 
 class CourseOfAction:
@@ -10,75 +8,75 @@ class CourseOfAction:
         self.opencti = opencti
         self.properties = """
             id
-            stix_id_key
-            stix_label
+            standard_id
             entity_type
             parent_types
-            name
-            alias
-            description
-            confidence
-            graph_data
-            created
-            modified            
+            spec_version
             created_at
             updated_at
-            createdByRef {
-                node {
+            createdBy {
+                ... on Identity {
                     id
+                    standard_id
                     entity_type
-                    stix_id_key
-                    stix_label
+                    parent_types
+                    spec_version
                     name
-                    alias
                     description
+                    roles
+                    contact_information
+                    x_opencti_aliases
                     created
                     modified
-                    ... on Organization {
-                        organization_class
-                    }
+                    objectLabel {
+                        edges {
+                            node {
+                                id
+                                value
+                                color
+                            }
+                        }
+                    }                    
                 }
-                relation {
-                    id
+                ... on Organization {
+                    x_opencti_organization_type
+                    x_opencti_reliability
                 }
-            }            
-            markingDefinitions {
+                ... on Individual {
+                    x_opencti_firstname
+                    x_opencti_lastname
+                }
+            }
+            objectMarking {
                 edges {
                     node {
                         id
+                        standard_id
                         entity_type
-                        stix_id_key
                         definition_type
                         definition
-                        level
-                        color
                         created
                         modified
-                    }
-                    relation {
-                        id
+                        x_opencti_order
+                        x_opencti_color
                     }
                 }
             }
-            tags {
+            objectLabel {
                 edges {
                     node {
                         id
-                        tag_type
                         value
                         color
                     }
-                    relation {
-                        id
-                    }
                 }
             }
             externalReferences {
                 edges {
                     node {
                         id
+                        standard_id
                         entity_type
-                        stix_id_key
                         source_name
                         description
                         url
@@ -87,11 +85,16 @@ class CourseOfAction:
                         created
                         modified
                     }
-                    relation {
-                        id
-                    }
                 }
-            }         
+            }
+            revoked
+            confidence
+            created
+            modified
+            name
+            description
+            x_opencti_aliases
+            x_mitre_id
         """
 
     """
@@ -123,8 +126,8 @@ class CourseOfAction:
         )
         query = (
             """
-            query CourseOfActions($filters: [CourseOfActionsFiltering], $search: String, $first: Int, $after: ID, $orderBy: CoursesOfActionOrdering, $orderMode: OrderingMode) {
-                courseOfActions(filters: $filters, search: $search, first: $first, after: $after, orderBy: $orderBy, orderMode: $orderMode) {
+            query CoursesOfAction($filters: [CoursesOfActionFiltering], $search: String, $first: Int, $after: ID, $orderBy: CoursesOfActionOrdering, $orderMode: OrderingMode) {
+                coursesOfAction(filters: $filters, search: $search, first: $first, after: $after, orderBy: $orderBy, orderMode: $orderMode) {
                     edges {
                         node {
                             """
@@ -155,7 +158,7 @@ class CourseOfAction:
             },
         )
         return self.opencti.process_multiple(
-            result["data"]["courseOfActions"], with_pagination
+            result["data"]["coursesOfAction"], with_pagination
         )
 
     """
@@ -210,17 +213,22 @@ class CourseOfAction:
         :return Course Of Action object
     """
 
-    def create_raw(self, **kwargs):
-        name = kwargs.get("name", None)
-        description = kwargs.get("description", None)
-        alias = kwargs.get("alias", None)
-        id = kwargs.get("id", None)
-        stix_id_key = kwargs.get("stix_id_key", None)
+    def create(self, **kwargs):
+        stix_id = kwargs.get("stix_id", None)
+        created_by = kwargs.get("createdBy", None)
+        object_marking = kwargs.get("objectMarking", None)
+        object_label = kwargs.get("objectLabel", None)
+        external_references = kwargs.get("externalReferences", None)
+        revoked = kwargs.get("revoked", None)
+        confidence = kwargs.get("confidence", None)
+        lang = kwargs.get("lang", None)
         created = kwargs.get("created", None)
         modified = kwargs.get("modified", None)
-        created_by_ref = kwargs.get("createdByRef", None)
-        marking_definitions = kwargs.get("markingDefinitions", None)
-        tags = kwargs.get("tags", None)
+        name = kwargs.get("name", None)
+        description = kwargs.get("description", "")
+        x_opencti_aliases = kwargs.get("x_opencti_aliases", None)
+        x_mitre_id = kwargs.get("x_mitre_id", None)
+        update = kwargs.get("update", False)
 
         if name is not None and description is not None:
             self.opencti.log("info", "Creating Course Of Action {" + name + "}.")
@@ -228,7 +236,7 @@ class CourseOfAction:
                 mutation CourseOfActionAdd($input: CourseOfActionAddInput) {
                     courseOfActionAdd(input: $input) {
                         id
-                        stix_id_key
+                        standard_id
                         entity_type
                         parent_types
                     }
@@ -238,16 +246,21 @@ class CourseOfAction:
                 query,
                 {
                     "input": {
-                        "name": name,
-                        "description": description,
-                        "alias": alias,
-                        "internal_id_key": id,
-                        "stix_id_key": stix_id_key,
+                        "stix_id": stix_id,
+                        "createdBy": created_by,
+                        "objectMarking": object_marking,
+                        "objectLabel": object_label,
+                        "externalReferences": external_references,
+                        "revoked": revoked,
+                        "confidence": confidence,
+                        "lang": lang,
                         "created": created,
                         "modified": modified,
-                        "createdByRef": created_by_ref,
-                        "markingDefinitions": marking_definitions,
-                        "tags": tags,
+                        "name": name,
+                        "description": description,
+                        "x_opencti_aliases": x_opencti_aliases,
+                        "x_mitre_id": x_mitre_id,
+                        "update": update,
                     }
                 },
             )
@@ -261,125 +274,63 @@ class CourseOfAction:
             )
 
     """
-        Create a Course Of Action object only if it not exists, update it on request
+        Import an Course-Of-Action object from a STIX2 object
 
-        :param name: the name of the Course Of Action
-        :return Course Of Action object
-    """
-
-    def create(self, **kwargs):
-        name = kwargs.get("name", None)
-        description = kwargs.get("description", None)
-        alias = kwargs.get("alias", None)
-        id = kwargs.get("id", None)
-        stix_id_key = kwargs.get("stix_id_key", None)
-        created = kwargs.get("created", None)
-        modified = kwargs.get("modified", None)
-        created_by_ref = kwargs.get("createdByRef", None)
-        marking_definitions = kwargs.get("markingDefinitions", None)
-        tags = kwargs.get("tags", None)
-        update = kwargs.get("update", False)
-        custom_attributes = """
-            id
-            entity_type
-            name
-            description 
-            alias
-            createdByRef {
-                node {
-                    id
-                }
-            }            
-        """
-        object_result = self.opencti.stix_domain_entity.get_by_stix_id_or_name(
-            types=["Course-Of-Action"],
-            stix_id_key=stix_id_key,
-            name=name,
-            customAttributes=custom_attributes,
-        )
-        if object_result is not None:
-            if update or object_result["createdByRefId"] == created_by_ref:
-                # name
-                if object_result["name"] != name:
-                    self.opencti.stix_domain_entity.update_field(
-                        id=object_result["id"], key="name", value=name
-                    )
-                    object_result["name"] = name
-                # description
-                if (
-                    self.opencti.not_empty(description)
-                    and object_result["description"] != description
-                ):
-                    self.opencti.stix_domain_entity.update_field(
-                        id=object_result["id"], key="description", value=description
-                    )
-                    object_result["description"] = description
-                # alias
-                if self.opencti.not_empty(alias) and object_result["alias"] != alias:
-                    if "alias" in object_result:
-                        new_aliases = object_result["alias"] + list(
-                            set(alias) - set(object_result["alias"])
-                        )
-                    else:
-                        new_aliases = alias
-                    self.opencti.stix_domain_entity.update_field(
-                        id=object_result["id"], key="alias", value=new_aliases
-                    )
-                    object_result["alias"] = new_aliases
-            return object_result
-        else:
-            return self.create_raw(
-                name=name,
-                description=description,
-                alias=alias,
-                id=id,
-                stix_id_key=stix_id_key,
-                created=created,
-                modified=modified,
-                createdByRef=created_by_ref,
-                markingDefinitions=marking_definitions,
-                tags=tags,
-            )
-
-    """
-        Export an Course-Of-Action object in STIX2
-    
-        :param id: the id of the Course-Of-Action
+        :param stixObject: the Stix-Object Course-Of-Action
         :return Course-Of-Action object
     """
 
-    def to_stix2(self, **kwargs):
-        id = kwargs.get("id", None)
-        mode = kwargs.get("mode", "simple")
-        max_marking_definition_entity = kwargs.get(
-            "max_marking_definition_entity", None
-        )
-        entity = kwargs.get("entity", None)
-        if id is not None and entity is None:
-            entity = self.read(id=id)
-        if entity is not None:
-            course_of_action = dict()
-            course_of_action["id"] = entity["stix_id_key"]
-            course_of_action["type"] = "course-of-action"
-            course_of_action["spec_version"] = SPEC_VERSION
-            course_of_action["name"] = entity["name"]
-            if self.opencti.not_empty(entity["stix_label"]):
-                course_of_action["labels"] = entity["stix_label"]
-            else:
-                course_of_action["labels"] = ["course-of-action"]
-            if self.opencti.not_empty(entity["description"]):
-                course_of_action["description"] = entity["description"]
-            course_of_action["created"] = self.opencti.stix2.format_date(
-                entity["created"]
-            )
-            course_of_action["modified"] = self.opencti.stix2.format_date(
-                entity["modified"]
-            )
-            if self.opencti.not_empty(entity["alias"]):
-                course_of_action[CustomProperties.ALIASES] = entity["alias"]
-            course_of_action[CustomProperties.ID] = entity["id"]
-            return self.opencti.stix2.prepare_export(
-                entity, course_of_action, mode, max_marking_definition_entity
+    def import_from_stix2(self, **kwargs):
+        stix_object = kwargs.get("stixObject", None)
+        extras = kwargs.get("extras", {})
+        update = kwargs.get("update", False)
+        if stix_object is not None:
+            # Extract external ID
+            x_mitre_id = None
+            if "x_mitre_id" in stix_object:
+                x_mitre_id = stix_object["x_mitre_id"]
+            if "external_references" in stix_object:
+                for external_reference in stix_object["external_references"]:
+                    if (
+                        external_reference["source_name"] == "mitre-attack"
+                        or external_reference["source_name"] == "mitre-pre-attack"
+                        or external_reference["source_name"] == "mitre-mobile-attack"
+                        or external_reference["source_name"] == "amitt-attack"
+                    ):
+                        x_mitre_id = external_reference["external_id"]
+
+            return self.create(
+                stix_id=stix_object["id"],
+                createdBy=extras["created_by_id"]
+                if "created_by_id" in extras
+                else None,
+                objectMarking=extras["object_marking_ids"]
+                if "object_marking_ids" in extras
+                else None,
+                objectLabel=extras["object_label_ids"]
+                if "object_label_ids" in extras
+                else [],
+                externalReferences=extras["external_references_ids"]
+                if "external_references_ids" in extras
+                else [],
+                revoked=stix_object["revoked"] if "revoked" in stix_object else None,
+                confidence=stix_object["confidence"]
+                if "confidence" in stix_object
+                else None,
+                lang=stix_object["lang"] if "lang" in stix_object else None,
+                created=stix_object["created"] if "created" in stix_object else None,
+                modified=stix_object["modified"] if "modified" in stix_object else None,
+                name=stix_object["name"],
+                description=self.opencti.stix2.convert_markdown(
+                    stix_object["description"]
+                )
+                if "description" in stix_object
+                else "",
+                x_opencti_aliases=self.opencti.stix2.pick_aliases(stix_object),
+                x_mitre_id=x_mitre_id,
+                update=update,
             )
         else:
-            self.opencti.log("error", "Missing parameters: id or entity")
+            self.opencti.log(
+                "error", "[opencti_course_of_action] Missing parameters: stixObject"
+            )
