@@ -291,7 +291,7 @@ class StixCyberObservable:
         types = kwargs.get("types", None)
         filters = kwargs.get("filters", None)
         search = kwargs.get("search", None)
-        first = kwargs.get("first", 500)
+        first = kwargs.get("first", 100)
         after = kwargs.get("after", None)
         order_by = kwargs.get("orderBy", None)
         order_mode = kwargs.get("orderMode", None)
@@ -300,7 +300,7 @@ class StixCyberObservable:
         with_pagination = kwargs.get("withPagination", False)
 
         if get_all:
-            first = 500
+            first = 100
 
         self.opencti.log(
             "info",
@@ -471,7 +471,7 @@ class StixCyberObservable:
         elif type.lower() == "x-opencti-cryptographic-key":
             type = "X-OpenCTI-Cryptographic-Key"
         elif type.lower() == "x-opencti-text":
-            type = "X-OpenCTI-text"
+            type = "X-OpenCTI-Text"
 
         x_opencti_description = (
             observable_data["x_opencti_description"]
@@ -712,9 +712,6 @@ class StixCyberObservable:
             elif type == "StixFile":
                 input_variables["StixFile"] = {
                     "hashes": hashes if len(hashes) > 0 else None,
-                    "extensions": observable_data["extensions"]
-                    if "extensions" in observable_data
-                    else None,
                     "size": observable_data["size"]
                     if "size" in observable_data
                     else None,
@@ -814,9 +811,6 @@ class StixCyberObservable:
                 }
             elif type == "Network-Traffic":
                 input_variables["NetworkTraffic"] = {
-                    "extensions": observable_data["extensions"]
-                    if "extensions" in observable_data
-                    else None,
                     "start": observable_data["start"]
                     if "start" in observable_data
                     else None,
@@ -848,9 +842,6 @@ class StixCyberObservable:
                 }
             elif type == "Process":
                 input_variables["Process"] = {
-                    "extensions": observable_data["extensions"]
-                    if "extensions" in observable_data
-                    else None,
                     "is_hidden": observable_data["is_hidden"]
                     if "is_hidden" in observable_data
                     else None,
@@ -893,9 +884,6 @@ class StixCyberObservable:
                 }
             elif type == "User-Account":
                 input_variables["UserAccount"] = {
-                    "extensions": observable_data["extensions"]
-                    if "extensions" in observable_data
-                    else None,
                     "user_id": observable_data["user_id"]
                     if "user_id" in observable_data
                     else None,
@@ -953,7 +941,6 @@ class StixCyberObservable:
                     if "number_of_subkeys" in observable_data
                     else None,
                 }
-                print(input_variables)
             elif type == "Windows-Registry-Value-Type":
                 input_variables["WindowsRegistryKeyValueType"] = {
                     "name": observable_data["name"]
@@ -1262,7 +1249,7 @@ class StixCyberObservable:
                     "error", "Cannot add Marking-Definition, entity not found"
                 )
                 return False
-            if marking_definition_id in stix_cyber_observable["markingDefinitionsIds"]:
+            if marking_definition_id in stix_cyber_observable["objectMarkingIds"]:
                 return True
             else:
                 self.opencti.log(
